import { K as etherUnits, L as formatUnits } from './chunk-TSH6VVF4.js';

/**
 * Multiplies a string representation of a number by a given exponent of base 10 (10exponent).
 *
 * - Docs: https://viem.sh/docs/utilities/parseUnits.html
 *
 * @example
 * import { parseUnits } from 'viem'
 *
 * parseUnits('420', 9)
 * // 420000000000n
 */
function parseUnits(value, decimals) {
    let [integer, fraction = '0'] = value.split('.');
    const negative = integer.startsWith('-');
    if (negative)
        integer = integer.slice(1);
    // trim leading zeros.
    fraction = fraction.replace(/(0+)$/, '');
    // round off if the fraction is larger than the number of decimals.
    if (decimals === 0) {
        if (Math.round(Number(`.${fraction}`)) === 1)
            integer = `${BigInt(integer) + 1n}`;
        fraction = '';
    }
    else if (fraction.length > decimals) {
        const [left, unit, right] = [
            fraction.slice(0, decimals - 1),
            fraction.slice(decimals - 1, decimals),
            fraction.slice(decimals),
        ];
        const rounded = Math.round(Number(`${unit}.${right}`));
        if (rounded > 9)
            fraction = `${BigInt(left) + BigInt(1)}0`.padStart(left.length + 1, '0');
        else
            fraction = `${left}${rounded}`;
        if (fraction.length > decimals) {
            fraction = fraction.slice(1);
            integer = `${BigInt(integer) + 1n}`;
        }
        fraction = fraction.slice(0, decimals);
    }
    else {
        fraction = fraction.padEnd(decimals, '0');
    }
    return BigInt(`${negative ? '-' : ''}${integer}${fraction}`);
}

/**
 * Converts a string representation of ether to numerical wei.
 *
 * - Docs: https://viem.sh/docs/utilities/parseEther.html
 *
 * @example
 * import { parseEther } from 'viem'
 *
 * parseEther('420')
 * // 420000000000000000000n
 */
function parseEther(ether, unit = 'wei') {
    return parseUnits(ether, etherUnits[unit]);
}

const MAINNET_APE_COIN_ADDRESS = '0x4d224452801aced8b2f0aebe155379bb5d594381';
const GOERLI_APE_COIN_ADDRESS = '0x9e1b542650A44C01f4bc6472F88d48eeDDf9aa75';
const erc20ABI = [
    {
        inputs: [
            {
                internalType: 'address',
                name: 'spender',
                type: 'address',
            },
            {
                internalType: 'uint256',
                name: 'addedValue',
                type: 'uint256',
            },
        ],
        name: 'increaseAllowance',
        outputs: [
            {
                internalType: 'bool',
                name: '',
                type: 'bool',
            },
        ],
        stateMutability: 'nonpayable',
        type: 'function',
    },
    {
        inputs: [
            {
                internalType: 'address',
                name: 'owner',
                type: 'address',
            },
            {
                internalType: 'address',
                name: 'spender',
                type: 'address',
            },
        ],
        name: 'allowance',
        outputs: [
            {
                internalType: 'uint256',
                name: '',
                type: 'uint256',
            },
        ],
        stateMutability: 'view',
        type: 'function',
    },
    {
        inputs: [
            {
                internalType: 'address',
                name: 'account',
                type: 'address',
            },
        ],
        name: 'balanceOf',
        outputs: [
            {
                internalType: 'uint256',
                name: '',
                type: 'uint256',
            },
        ],
        stateMutability: 'view',
        type: 'function',
    },
    {
        inputs: [],
        name: 'decimals',
        outputs: [
            {
                internalType: 'uint8',
                name: '',
                type: 'uint8',
            },
        ],
        stateMutability: 'view',
        type: 'function',
    },
];
/**
 * Converts an ERC20 token amount (in its native decimal format) back to its equivalent in Wei (18 decimals).
 *
 * @param client - The client to use for reading the ERC20 token's decimals.
 * @param erc20address - The Ethereum address of the ERC20 token, prefixed with `0x`.
 * @param value - The ERC20 token amount in its native decimals.
 * @returns The value converted back to Wei format.
 */
const convertERC20DecimalsToWei = async (client, erc20address, value // the ERC20 token amount in its native decimals
) => {
    const decimals = await client.readContract({
        abi: erc20ABI,
        address: erc20address,
        functionName: 'decimals',
    });
    return parseEther(formatUnits(value, decimals));
};
/**
 * Gets the balance of an ERC20 token for a specific address.
 *
 * @param client - The client to use for reading the ERC20 token's decimals.
 * @param erc20address - The Ethereum address of the ERC20 token, prefixed with `0x`.
 * @param address - The Ethereum address of the account, prefixed with `0x`.
 * @returns The balance in ERC20 token's decimal format.
 */
const getBalance = async (client, erc20address, address) => {
    return client.readContract({
        abi: erc20ABI,
        address: erc20address,
        functionName: 'balanceOf',
        args: [address],
    });
};
/**
 * Gets the allowance of an ERC20 token for a specific address.
 *
 * @param client - The client to use for reading the ERC20 token's decimals.
 * @param erc20address - The Ethereum address of the ERC20 token, prefixed with `0x`.
 * @param owner - The Ethereum address of the account, prefixed with `0x`.
 * @param spender - The Ethereum address of the spender, prefixed with `0x`.
 * @returns The allowance in ERC20 token's decimal format.
 */
const getAllowance = async (client, erc20address, owner, spender) => {
    return client.readContract({
        abi: erc20ABI,
        address: erc20address,
        functionName: 'allowance',
        args: [owner, spender],
    });
};
/**
 * Increases the allowance of an ERC20 token for a specific address.
 *
 * @param client - The client to use for reading the ERC20 token's decimals.
 * @param walletClient - The client to use for writing the transaction.
 * @param erc20address - The Ethereum address of the ERC20 token, prefixed with `0x`.
 * @param address - The Ethereum address of the account, prefixed with `0x`.
 * @param amount - The amount to increase the allowance by, in ERC20 token's decimal format.
 * @returns The allowance in ERC20 token's decimal format.
 */
const increaseAllowance = async (client, walletClient, erc20address, address, amount) => {
    const [account] = await walletClient.getAddresses();
    const { request, result } = await client.simulateContract({
        account,
        abi: erc20ABI,
        address: erc20address,
        functionName: 'increaseAllowance',
        args: [address, amount],
    });
    if (!result) {
        throw new Error('Something went wrong.');
    }
    return walletClient.writeContract(Object.assign(Object.assign({}, request), { account }));
};

export { GOERLI_APE_COIN_ADDRESS as G, MAINNET_APE_COIN_ADDRESS as M, getAllowance as a, convertERC20DecimalsToWei as c, getBalance as g, increaseAllowance as i };

//# sourceMappingURL=erc20.js.map